@@ -1,8 +1,8 @@
 # coding: utf-8
-from pyotrs.lib import Article
+from otrs_somconnexio.otrs_models.abstract_article import AbstractArticle
 
 
-class CoverageArticle:
+class CoverageArticle(AbstractArticle):
     """
     This entity gets created from a CoverageTicket.
     """
@@ -11,21 +11,16 @@ class CoverageArticle:
         "poblacioServei", "provinciaServei", "CPservei", "altresCobertura", "coberturaADSL",
         "coberturaFibraMM", "coberturaFibraVdf", "IDhogar"
     )
+    subject = "Sol·licitud cobertura"
 
     def __init__(self, ticket):
         self.ticket = ticket
-
-    def build(self):
-        return Article({
-            "Subject": "Sol·licitud cobertura",
-            "Body": self._body(),
-            "ContentType": "text/plain; charset=utf8"
-        })
+        self.body = self._body()
 
     def _body(self):
         body = ""
         for df_name in self.dynamic_fields_names:
-            df_value = self.ticket.getattr(df_name)
+            df_value = getattr(self.ticket, df_name)
             if df_value:
                 body = u"{}{}: {}\n".format(body, df_name, df_value)
         return body
