@@ -12,4 +12,5 @@ class CoverageTicket:
         With this method we implement a decorator pattern.
         This reads from the response and hides the details of the dynamic fields.
         """
-        return self.ticket.response.dynamic_field_get(attr).value
+        dynamic_field = self.ticket.response.dynamic_field_get(attr)
+        return dynamic_field.value if dynamic_field else ""
