@@ -19,5 +19,5 @@ class UpdateProcessTicketWithCoverageTicketsInfoService:
         otrs_client = OTRSClient()
 
         for ticket in self.coverage_tickets:
-            article = CoverageArticle(ticket).build()
+            article = CoverageArticle(ticket).call()
             otrs_client.update_ticket(self.ticket_id, article)
