@@ -29,26 +29,26 @@ class FiberTicketTestCase(unittest.TestCase):
         eticom_contract.party = party
 
         otrs_configuration = Mock(spec=[
-            'fibre_ticket_type',
-            'fibre_ticket_queue',
-            'fibre_ticket_state',
-            'fibre_ticket_priority',
-            'fibre_process_id',
-            'fibre_activity_id',
+            'fiber_ticket_type',
+            'fiber_ticket_queue',
+            'fiber_ticket_state',
+            'fiber_ticket_priority',
+            'fiber_process_id',
+            'fiber_activity_id',
         ])
-        otrs_configuration.fibre_ticket_type = 'fiber_ticket_type'
-        otrs_configuration.fibre_ticket_queue = 'fiber_ticket_queue'
-        otrs_configuration.fibre_ticket_state = 'fiber_ticket_state'
-        otrs_configuration.fibre_ticket_proprity = 'fiber_ticket_priority'
-        otrs_configuration.fibre_process_id = 'fiber_process_id'
-        otrs_configuration.fibre_activity_id = 'fiber_activity_id'
+        otrs_configuration.fiber_ticket_type = 'fiber_ticket_type'
+        otrs_configuration.fiber_ticket_queue = 'fiber_ticket_queue'
+        otrs_configuration.fiber_ticket_state = 'fiber_ticket_state'
+        otrs_configuration.fiber_ticket_proprity = 'fiber_ticket_priority'
+        otrs_configuration.fiber_process_id = 'fiber_process_id'
+        otrs_configuration.fiber_activity_id = 'fiber_activity_id'
 
         expected_ticket_arguments = {
             "Title": "Sol·licitud fiber {}".format(eticom_contract.id),
-            "Type": otrs_configuration.fibre_ticket_type,
-            "Queue": otrs_configuration.fibre_ticket_queue,
-            "State": otrs_configuration.fibre_ticket_state,
-            "Priority": otrs_configuration.fibre_ticket_proprity,
+            "Type": otrs_configuration.fiber_ticket_type,
+            "Queue": otrs_configuration.fiber_ticket_queue,
+            "State": otrs_configuration.fiber_ticket_state,
+            "Priority": otrs_configuration.fiber_ticket_proprity,
             "CustomerUser": 'contact@mail.com',
             "CustomerID": 'contact@mail.com'
         }
@@ -71,19 +71,19 @@ class FiberTicketTestCase(unittest.TestCase):
         eticom_contract.party = party
 
         otrs_configuration = Mock(spec=[
-            'fibre_ticket_type',
-            'fibre_ticket_queue',
-            'fibre_ticket_state',
-            'fibre_ticket_priority',
-            'fibre_process_id',
-            'fibre_activity_id',
+            'fiber_ticket_type',
+            'fiber_ticket_queue',
+            'fiber_ticket_state',
+            'fiber_ticket_priority',
+            'fiber_process_id',
+            'fiber_activity_id',
         ])
-        otrs_configuration.fibre_ticket_type = 'fiber_ticket_type'
-        otrs_configuration.fibre_ticket_queue = 'fiber_ticket_queue'
-        otrs_configuration.fibre_ticket_state = 'fiber_ticket_state'
-        otrs_configuration.fibre_ticket_proprity = 'fiber_ticket_priority'
-        otrs_configuration.fibre_process_id = 'fiber_process_id'
-        otrs_configuration.fibre_activity_id = 'fiber_activity_id'
+        otrs_configuration.fiber_ticket_type = 'fiber_ticket_type'
+        otrs_configuration.fiber_ticket_queue = 'fiber_ticket_queue'
+        otrs_configuration.fiber_ticket_state = 'fiber_ticket_state'
+        otrs_configuration.fiber_ticket_proprity = 'fiber_ticket_priority'
+        otrs_configuration.fiber_process_id = 'fiber_process_id'
+        otrs_configuration.fiber_activity_id = 'fiber_activity_id'
 
         with self.assertRaises(CustomerMailMissing):
             FiberTicket(eticom_contract, otrs_configuration)._build_ticket()
@@ -98,19 +98,19 @@ class FiberTicketTestCase(unittest.TestCase):
         eticom_contract.party = None
 
         otrs_configuration = Mock(spec=[
-            'fibre_ticket_type',
-            'fibre_ticket_queue',
-            'fibre_ticket_state',
-            'fibre_ticket_priority',
-            'fibre_process_id',
-            'fibre_activity_id',
+            'fiber_ticket_type',
+            'fiber_ticket_queue',
+            'fiber_ticket_state',
+            'fiber_ticket_priority',
+            'fiber_process_id',
+            'fiber_activity_id',
         ])
-        otrs_configuration.fibre_ticket_type = 'fiber_ticket_type'
-        otrs_configuration.fibre_ticket_queue = 'fiber_ticket_queue'
-        otrs_configuration.fibre_ticket_state = 'fiber_ticket_state'
-        otrs_configuration.fibre_ticket_proprity = 'fiber_ticket_priority'
-        otrs_configuration.fibre_process_id = 'fiber_process_id'
-        otrs_configuration.fibre_activity_id = 'fiber_activity_id'
+        otrs_configuration.fiber_ticket_type = 'fiber_ticket_type'
+        otrs_configuration.fiber_ticket_queue = 'fiber_ticket_queue'
+        otrs_configuration.fiber_ticket_state = 'fiber_ticket_state'
+        otrs_configuration.fiber_ticket_proprity = 'fiber_ticket_priority'
+        otrs_configuration.fiber_process_id = 'fiber_process_id'
+        otrs_configuration.fiber_activity_id = 'fiber_activity_id'
 
         with self.assertRaises(CustomerUserMissing):
             FiberTicket(eticom_contract, otrs_configuration)._build_ticket()
@@ -134,11 +134,11 @@ class FiberTicketTestCase(unittest.TestCase):
         eticom_contract = Mock(spec=[])
 
         otrs_configuration = Mock(spec=[
-            'fibre_process_id'
-            'fibre_activity_id'
+            'fiber_process_id'
+            'fiber_activity_id'
         ])
-        otrs_configuration.fibre_process_id = 'fiber_process_id'
-        otrs_configuration.fibre_activity_id = 'fiber_activity_id'
+        otrs_configuration.fiber_process_id = 'fiber_process_id'
+        otrs_configuration.fiber_activity_id = 'fiber_activity_id'
 
         mock_fiber_dynamic_fields = MockFiberDynamicFields.return_value
 
@@ -146,8 +146,8 @@ class FiberTicketTestCase(unittest.TestCase):
 
         MockFiberDynamicFields.assert_called_with(
             eticom_contract,
-            otrs_configuration.fibre_process_id,
-            otrs_configuration.fibre_activity_id,
+            otrs_configuration.fiber_process_id,
+            otrs_configuration.fiber_activity_id,
         )
         mock_fiber_dynamic_fields.all.assert_called_once()
 
@@ -193,12 +193,12 @@ class FiberTicketTestCase(unittest.TestCase):
         eticom_contract.bank_iban_service = "ES6621000418401234567891"
 
         otrs_configuration = Mock(spec=[
-            'fibre_ticket_type',
-            'fibre_ticket_queue',
-            'fibre_ticket_state',
-            'fibre_ticket_proprity',
-            'fibre_process_id',
-            'fibre_activity_id',
+            'fiber_ticket_type',
+            'fiber_ticket_queue',
+            'fiber_ticket_state',
+            'fiber_ticket_proprity',
+            'fiber_process_id',
+            'fiber_activity_id',
         ])
 
         mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
