@@ -22,7 +22,10 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.party = Mock(spec=[
             'first_name',
             'name',
-            'get_identifier'])
+            'get_identifier',
+            'get_contact_email',
+            'get_contact_phone'
+        ])
         self.eticom_contract = Mock(spec=[
             'id',
             'party',
@@ -33,6 +36,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             'mobile_min',
             'mobile_internet',
             'mobile_option',
+            'mobile_telecom_company',
         ])
         self.eticom_contract.mobile_option = 'new'
         self.eticom_contract.mobile_min = '0'
@@ -260,3 +264,73 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["IBAN"], "ES6621000418401234567891")
+
+    def test_contact_email_field(self):
+        mock_email = Mock(spec=["value"])
+        mock_email.value = "test@email.org"
+        self.party.get_contact_email.return_value = mock_email
+
+        self.eticom_contract.party = self.party
+
+        dynamic_fields = MobileDynamicFields(
+            self.eticom_contract,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["correuElectronic"], "test@email.org")
+
+    def test_contact_phone_field(self):
+        mock_phone = Mock(spec=["value"])
+        mock_phone.value = "666666666"
+        self.party.get_contact_phone.return_value = mock_phone
+
+        self.eticom_contract.party = self.party
+
+        dynamic_fields = MobileDynamicFields(
+            self.eticom_contract,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["telefonContacte"], "666666666")
+
+    def test_none_previous_provider_field(self):
+        self.eticom_contract.mobile_telecom_company = None
+
+        dynamic_fields = MobileDynamicFields(
+            self.eticom_contract,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["operadorDonantMobil"], "None")
+
+    def test_other_previous_provider_field(self):
+        self.eticom_contract.mobile_telecom_company = Mock(spec=[])
+        self.eticom_contract.mobile_telecom_company.name = "NewProvider"
+
+        dynamic_fields = MobileDynamicFields(
+            self.eticom_contract,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["operadorDonantMobil"], "Other")
+
+    def test_mapped_previous_provider_field(self):
+        self.eticom_contract.mobile_telecom_company = Mock(spec=[])
+        self.eticom_contract.mobile_telecom_company.name = "Aire / Nubip"
+
+        dynamic_fields = MobileDynamicFields(
+            self.eticom_contract,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["operadorDonantMobil"], "AireNubip")
