@@ -2,7 +2,8 @@
 import unittest
 from mock import Mock, patch
 
-from otrs_somconnexio.services.update_process_ticket_with_coverage_tickets_info_service import UpdateProcessTicketWithCoverageTicketsInfoService
+from otrs_somconnexio.services.update_process_ticket_with_coverage_tickets_info_service import \
+    UpdateProcessTicketWithCoverageTicketsInfoService
 
 
 class UpdateProcessTicketWithCoverageTicketsInfoServiceTestCase(unittest.TestCase):
@@ -17,8 +18,8 @@ class UpdateProcessTicketWithCoverageTicketsInfoServiceTestCase(unittest.TestCas
 
         def mock_coverage_article_side_effect(ticket):
             if ticket == expected_coverage_ticket:
-                mock_coverage_article = Mock(spec=['build'])
-                mock_coverage_article.build.return_value = coverage_article
+                mock_coverage_article = Mock(spec=['call'])
+                mock_coverage_article.call.return_value = coverage_article
                 return mock_coverage_article
 
         MockCoverageArticle.side_effect = mock_coverage_article_side_effect
